#!/bin/sh

# bb-disable.sh
#
# Robert-Andre Croteau
# Version 1.4g
# May 12th, 2000
#
# This program is Copyright (c) 1997-2000
# Robert-Andre Croteau, The MacLawran Group Inc.
# All Rights Reserved
#

# Just make sure BB environment is set before executing
# Thanks to Jason Englander <jason@interl.net>

args=$1			# just keep what's needed
argnum=$#

if [ "$BBHOME" = "" -o ! -d "$BBHOME" ]
then
	echo "BBHOME is not set"
        exit 1
fi

. $BBHOME/etc/bbdef.sh

if [ "$args" = "" ]
then
	echo "Usage: bb-disable.sh \"<host(s) regular expression> <duration>\""
	exit 1
fi


if [ "$argnum" -ne 1 ]
then
	echo "Usage: bb-disable.sh \"<host(s) regular expression> <duration>\""
	exit 1
fi

set -f
set $args
set +f

if [ "$#" -eq 0 -o "$#" -gt 2 ]
then
	echo "Usage: bb-disable.sh \"<host(s) regular expression> <duration>\""
	exit 1
fi

hostsexp=$1
if [ "$#" -eq 2 ]
then
	value=`$EXPR "$2" + 0`
	if [ "$?" -ne 0 ]
	then
		echo "Usage: bb-disable.sh \"<host(s) regular expression> <duration>\""
		exit 1
	fi
	now=`$BBHOME/bin/touchtime -e`
	value=`$BBHOME/bin/touchtime -e "$2"`
	if [ "$value" -lt "$now" ]
	then
		echo "Usage: bb-disable.sh \"<host(s) regular expression> <duration>\""
		exit 1
	fi
	delay=$2
fi

# Go into the logs directory and get all of the hosts that match the regular expression
cd $BBLOGS
lsregexp=`echo "$hostsexp" | $SED 's/[,\.]/\[,\.\]/g'`
$LS -1 $lsregexp 2>/dev/null | $GREP -v "^\." >$BBTMP/BBDISABLE.$$ 2>/dev/null
if [ "$?" -ne 0 ]
then
	$RM -f $BBTMP/BBDISABLE.$$
	echo "bb-disable.sh: No hosts matched <$hostsexp> <$lsregexp>"
	exit 0
fi

#
# offline message should only go to local BBDISPLAY that started this script
# and ALL BBPAGERS ... This way we're sure that there's no SPOF
# to receive an offline message for the BBPAGERS.
#
BBDISP="0.0.0.0"
if [ "$BBPAGE" = "0.0.0.0" ]
then    
	BBDISPLAYS="$MACHINEADDR $BBPAGERS"
else    
	BBDISPLAYS="$MACHINEADDR $BBPAGE"
fi      

$CAT $BBTMP/BBDISABLE.$$ | \
while read host
do
	$BB $BBDISP "offline $host $delay"
done

$RM -f $BBTMP/BBDISABLE.$$
